@@ -1,7 +1,7 @@
 from contextlib import contextmanager
 from os import fchmod
 from pathlib import Path
-from typing import Iterator, TextIO
+from typing import Iterator, Optional, TextIO
 
 from sym.cli.helpers.contexts import push_env
 
@@ -10,9 +10,15 @@ class Sandbox:
     def __init__(self, path: Path) -> None:
         self.path = path
 
-    def create_file(self, name: str, mode: int = 0o644) -> None:
-        with self.create_file_with_content(name, mode):
-            pass
+    def create_binary(self, name):
+        self.create_file(name, mode=0o755, contents="#!/bin/bash\n")
+
+    def create_file(
+        self, name: str, mode: int = 0o644, contents: Optional[str] = None
+    ) -> None:
+        with self.create_file_with_content(name, mode) as f:
+            if contents:
+                f.write(contents)
 
     @contextmanager
     def create_file_with_content(
